//
//  ZTwoCutTableView.m
//  TwoCutTableView
//
//  Created by Crystal on 2017/6/7.
//  Copyright © 2017年 Tangdada. All rights reserved.
//

#import "ZTwoCutTableView.h"
#import "Masonry.h"

static const CGFloat zHeight = 50.0f;
static const CGFloat zLeftWidth = 80.0f; // 左边宽度
static const CGFloat zRightWidth = 100.0f; // 右边宽度／每个column

#define ScreenWidth [UIScreen mainScreen].bounds.size.width
#define ScreenHeight [UIScreen mainScreen].bounds.size.height

@interface ZTwoCutTableView () <UITableViewDelegate, UITableViewDataSource>
{
    NSInteger rightColumn; // 右边的栏目数
}

@property (nonatomic, strong) UILabel *leftTitleLabel;

@property (nonatomic, strong) UITableView *leftTableView;

@property (nonatomic, strong) UIScrollView *rightBgScrollView;

@property (nonatomic, strong) UITableView *rightTableView;

@end

@implementation ZTwoCutTableView

- (instancetype)init
{
    self = [super init];
    if (self) {
        [self setUpViews];
    }
    return self;
}

- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self setUpViews];
    }
    return self;
}

- (void)setLeftTitle:(NSString *)leftTitle {
    [_leftTitleLabel setText:leftTitle];
}

- (void)setRightTitles:(NSArray *)rightTitles {
    if (rightTitles.count > 0) {
        _rightTitles = rightTitles;
        rightColumn = _rightTitles.count;
        [self setUpRightTopViews];
    }
}

- (void)setLeftContents:(NSArray *)leftContents {
    _leftContents = leftContents;
}

- (void)setRightContents:(NSArray *)rightContents {
    _rightContents = rightContents;
    _rightBgScrollView.contentSize = CGSizeMake(rightColumn * zRightWidth, ScreenHeight);
    [_rightTableView mas_remakeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(_rightBgScrollView);
        make.top.equalTo(_leftTitleLabel.mas_bottom);
        make.width.mas_equalTo(rightColumn * zRightWidth);
        make.height.mas_equalTo(ScreenHeight - zHeight);
    }];
}

#pragma mark - UITableViewDelegate
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return _leftContents.count;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return zHeight;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    if (tableView == _leftTableView) {
        static NSString *cellIdentifier = @"leftTableViewCell";
        UITableViewCell *cell = [_leftTableView dequeueReusableCellWithIdentifier:cellIdentifier];
        if (!cell) {
            cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellIdentifier];
            UILabel *label = [[UILabel alloc] init];
            label.font = [UIFont systemFontOfSize:15.0f];
            label.textColor = [UIColor blackColor];
            label.textAlignment = NSTextAlignmentCenter;
            label.tag = 100;
            [cell.contentView addSubview:label];
            [label mas_makeConstraints:^(MASConstraintMaker *make) {
                make.edges.equalTo(cell.contentView);
            }];
        }
        UILabel *label = (UILabel *)[cell.contentView viewWithTag:100];
        [label setText:_leftContents[indexPath.row]];
        return cell;
    } else {
        static NSString *cellIdentifier = @"rightTableViewCell";
        UITableViewCell *cell = [_rightTableView dequeueReusableCellWithIdentifier:cellIdentifier];
        if (!cell) {
            cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellIdentifier];
            for (int i = 0; i < rightColumn; i++) {
                UILabel *label = [[UILabel alloc] init];
                label.font = [UIFont systemFontOfSize:15.0f];
                label.textColor = [UIColor blackColor];
                label.textAlignment = NSTextAlignmentCenter;
                label.tag = 200 + i;
                [cell.contentView addSubview:label];
                [label mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.left.mas_equalTo(i * zRightWidth);
                    make.top.equalTo(cell.contentView);
                    make.width.mas_equalTo(zRightWidth);
                    make.height.mas_equalTo(zHeight);
                }];
            }
        }
        for (int j = 0; j < rightColumn; j++) {
            UILabel *label = (UILabel *)[cell.contentView viewWithTag:200 + j];
            [label setText:_rightContents[indexPath.row][j]];
        }
        return cell;
    }
}

- (void)scrollViewDidScroll:(UIScrollView *)scrollView {
    if (scrollView == _leftTableView) {
        _rightTableView.contentOffset = CGPointMake(_leftTableView.contentOffset.x, _leftTableView.contentOffset.y);
    } else {
        _leftTableView.contentOffset = CGPointMake(0, _rightTableView.contentOffset.y);
    }
}

#pragma mark - create UI
- (void)setUpViews {
    _leftTitleLabel = [[UILabel alloc] init];
    _leftTitleLabel.font = [UIFont systemFontOfSize:15.0f];
    _leftTitleLabel.textColor = [UIColor blackColor];
    _leftTitleLabel.backgroundColor = [[UIColor lightGrayColor] colorWithAlphaComponent:0.6];
    _leftTitleLabel.textAlignment = NSTextAlignmentCenter;
    [self addSubview:_leftTitleLabel];
    [_leftTitleLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(self);
        make.top.equalTo(self.mas_top).offset(64);
        make.width.mas_equalTo(zLeftWidth);
        make.height.mas_equalTo(zHeight);
    }];
    
    _leftTableView = [[UITableView alloc] init];
    _leftTableView.delegate = self;
    _leftTableView.dataSource = self;
    [self addSubview:_leftTableView];
    [_leftTableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(self);
        make.top.equalTo(_leftTitleLabel.mas_bottom);
        make.width.mas_equalTo(zLeftWidth);
        make.height.mas_equalTo(ScreenHeight - zHeight);
    }];
    _leftTableView.tableFooterView = [UIView new];
    
    _rightBgScrollView = [[UIScrollView alloc] init];
    _rightBgScrollView.bounces = NO;
    [self addSubview:_rightBgScrollView];
    [_rightBgScrollView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(_leftTableView.mas_right);
        make.top.equalTo(self.mas_top).offset(64);
        make.width.mas_equalTo(ScreenWidth - zLeftWidth);
        make.height.mas_equalTo(ScreenHeight);
    }];
    
    _rightTableView = [[UITableView alloc] init];
    _rightTableView.delegate = self;
    _rightTableView.dataSource = self;
    [_rightBgScrollView addSubview:_rightTableView];
    [_rightTableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(_rightBgScrollView);
        make.top.equalTo(_leftTitleLabel.mas_bottom);
        make.width.mas_equalTo(ScreenWidth - zRightWidth);
        make.height.mas_equalTo(ScreenHeight - zHeight);
    }];
    _rightTableView.tableFooterView = [UIView new];
}

- (void)setUpRightTopViews {
    for (int i = 0; i < _rightTitles.count; i++) {
        UILabel *label = [[UILabel alloc] init];
        label.font = [UIFont systemFontOfSize:15.0f];
        label.textColor = [UIColor blackColor];
        label.backgroundColor = [[UIColor lightGrayColor] colorWithAlphaComponent:0.4];
        label.textAlignment = NSTextAlignmentCenter;
        [label setText:_rightTitles[i]];
        [_rightBgScrollView addSubview:label];
        [label mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(zRightWidth * i);
            make.top.equalTo(_rightBgScrollView);
            make.width.mas_equalTo(zRightWidth);
            make.height.mas_equalTo(zHeight);
        }];
    }
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
